/* (C) 2011 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an IP address (actually, a TCP/UDP address).
 *
 * $Id: IPAddr.hh,v 1.1 2012/12/27 13:53:02 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _IP_ADDRESS_HH_
#define _IP_ADDRESS_HH_

#include <string>
#include <iostream>
#include "AddrInfo.hh"

namespace HTTPTunnel {

class IPAddr {
public:
	// Construction/destruction
	IPAddr();
	IPAddr(std::string host, unsigned int port);
	IPAddr(std::string host, unsigned int port, AddrInfo::Family family);
	IPAddr(const IPAddr& that);
	~IPAddr();

	// Operators
	IPAddr& operator=(const IPAddr& that);
	bool operator==(const IPAddr& that) const;

	// Accessors
	const std::string& getHost(void) const;
	unsigned int getPort(void) const;
	AddrInfo::Family getFamily(void) const;
	std::string getFamilyStr(void) const;

	// Mutators
	void setPort(unsigned int port);

private:

	/***********/
	/* Methods */
	/***********/

	// Set address family from host
	void setFamilyFromHost(AddrInfo::Family defaultFamily);


	/********/
	/* Data */
	/********/

	// Address details
	std::string				m_host;
	unsigned int			m_port;
	AddrInfo::Family		m_family;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const IPAddr& addr);


}	// namespace

#endif

