/* (C) 2009 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate IP address details.
 *
 * $Id: AddrInfo.cs,v 1.2 2013/02/17 10:52:29 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Net;
	using System.Net.Sockets;
	using System.Text;

	public class AddrInfo {

		/********************/
		/* Public Interface */
		/********************/


		/*********/
		/* Types */
		/*********/

		// Address family
		public enum Family { IPV4, IPV6, UNKNOWN_FAMILY };


		/***********/
		/* Methods */
		/***********/

		// Construction
		public AddrInfo(string host)
		{
			m_host = host;
			m_family = Family.UNKNOWN_FAMILY;
			m_addr = null;
			m_addrStr = "";
		}


		/*************/
		/* Accessors */
		/*************/

		// Get hostname as a string
		public string getHostName()
		{
			return m_host;
		}

		// Get address family
		public Family getFamily()
		{
			return m_family;
		}

		// Get address family as a string
		public string getFamilyStr()
		{
			return getFamilyStr(m_family);
		}

		// Get ref to socket address
		public EndPoint getAddr()
		{
			return m_addr;
		}

		// Get IP address as a string
		public string getAddrStr()
		{
			return m_addrStr;
		}


		/************/
		/* Mutators */
		/************/

		// Set address family
		public void setFamily(AddressFamily family)
		{
			if(family == AddressFamily.InterNetworkV6)
				m_family = Family.IPV6;
			else if(family == AddressFamily.InterNetwork)
				m_family = Family.IPV4;
			else
				m_family = Family.UNKNOWN_FAMILY;
		}

		// Set socket details
		public void setAddr(EndPoint addr)
		{
			m_addr = addr;
		}

		// Set IP address as a string
		public void setAddrStr(string addrStr)
		{
			m_addrStr = addrStr;
		}


		/***********/
		/* Utility */
		/***********/

		// Get address family constant as a string
		public static string getFamilyStr(Family family)
		{
			switch(family) {
				case(Family.IPV4):
					return "IPV4";
				case(Family.IPV6):
					return "IPV6";
				default:
					break;
			}

			return "UNKNOWN_FAMILY";
		}

		// Create a representation of ourselves as a string
		public override string ToString()
		{
			StringBuilder str = new StringBuilder();

			str.AppendFormat("Hostname: {0}", getHostName()); str.AppendLine();
			str.AppendFormat("Family: {0}", getFamilyStr()); str.AppendLine();
			str.AppendFormat("AddrStr: {0}", getAddrStr()); str.AppendLine();

			return str.ToString();
		}


		/*********************/
		/* Private Interface */
		/*********************/


		/********/
		/* Data */
		/********/

		// Hostname as a string
		private string					m_host;

		// Address family
		private Family					m_family;

		// Socket address
		private EndPoint				m_addr;

		// IP address as a string
		private string					m_addrStr;

	}

}	// namespace

