/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Perform HTTP digest authentication.
 *
 * $Id: AuthDigest.cs,v 1.2 2009/03/20 11:55:49 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;
	using System.Security.Cryptography;
	using Mono.Security.Cryptography;

	public class AuthDigest {

		public AuthDigest()
		{
		}


		// Calculate the response fields for digest authentication
		public static string MD5DigestResponse(string alg, string user, string passwd,
		string realm, string nonce, string cnonce, string cnoncec, string qop, string uri)
		{
			// Construct digest HA1
			string HA1 = DigestCalcHA1(alg, user, realm, passwd, nonce, cnonce);
			string HHResponse = DigestCalcResponse(HA1, nonce, cnoncec, cnonce,
				qop, "GET", uri, "");

			return HHResponse;
		}


		// Calculate raw MD4 digest
		public static void MD4Digest(byte[] str, byte[] md4)
		{
			// Initialise
			MD4 Md4Ctx = MD4.Create();
			Md4Ctx.Initialize();

			// Get digest
			byte[] digest = Md4Ctx.ComputeHash(str);

			// Copy for caller
			Array.Copy(digest, md4, digest.Length);
		}

		// Calculate string MD4 digest
		public static string MD4DigestStr(byte[] str)
		{
			// Get digest
			byte[] digest = new byte[16];
			MD4Digest(str, digest);

			// Convert to string and return
			return CvtHex(digest);
		}


		// Calculate raw MD5 digest
		public static void MD5Digest(byte[] str, byte[] md5)
		{
			// Initialise
			MD5 Md5Ctx = MD5.Create();
			Md5Ctx.Initialize();

			// Get digest
			byte[] digest = Md5Ctx.ComputeHash(str);

			// Copy for caller
			Array.Copy(digest, md5, digest.Length);
		}

		// Calculate string MD5 digest
		public static string MD5DigestStr(byte[] str)
		{
			// Get digest
			byte[] digest = new byte[16];
			MD5Digest(str, digest);

			// Convert to string and return
			return CvtHex(digest);
		}


		/*********************/
		/* Private Interface */
		/*********************/


		// Hex conversion
		private static string CvtHex(byte[] Bin)
		{
			StringBuilder str = new StringBuilder();
			foreach(byte b in Bin) {
				str.Append(b.ToString("x2").ToLower());
			}

			return str.ToString();
		}


		// Calculate H(A1) as per HTTP Digest spec
		private static string DigestCalcHA1(string alg, string userName, string realm,
		string passwd, string nonce, string cnonce)
		{
			MD5CryptoServiceProvider Md5Ctx = new MD5CryptoServiceProvider();
			Md5Ctx.Initialize();

			byte[] a1Bs = null;
			if(alg == "md5-sess") {
				a1Bs = System.Text.Encoding.UTF8.GetBytes(userName + ":" +
					realm + ":" + passwd + ":" + nonce + ":" + cnonce);
			}
			else {
				a1Bs = System.Text.Encoding.UTF8.GetBytes(userName + ":" +
					realm + ":" + passwd);
			}
			byte[] HA1 = Md5Ctx.ComputeHash(a1Bs);

			return CvtHex(HA1);
		}


		// Calculate request-digest/response-digest as per HTTP Digest spec
		private static string DigestCalcResponse(string HA1, string nonce, string nonceCount,
		string cnonce, string qop, string method, string uri, string hentity)
		{
			MD5CryptoServiceProvider Md5Ctx = new MD5CryptoServiceProvider();
			Md5Ctx.Initialize();

			// Calculate HA2
			byte[] a2Bs = null;
			if(qop == "auth-int") {
				a2Bs = System.Text.Encoding.UTF8.GetBytes(method + ":" + uri + ":" + hentity);
			}
			else {
				a2Bs = System.Text.Encoding.UTF8.GetBytes(method + ":" + uri);
			}
			byte[] HA2 = Md5Ctx.ComputeHash(a2Bs);

			// Calculate response
			Md5Ctx.Initialize();
			byte[] respBs = null;
			if(qop.Length > 0) {
				respBs = System.Text.Encoding.UTF8.GetBytes(HA1 + ":" + nonce + ":" +
					nonceCount + ":" + cnonce + ":" + qop + ":" + CvtHex(HA2));
			}
			else {
				respBs = System.Text.Encoding.UTF8.GetBytes(HA1 + ":" + nonce + ":" +
					CvtHex(HA2));
			}
			byte[] RespHash = Md5Ctx.ComputeHash(respBs);

			return CvtHex(RespHash);
		}

	}

}	// namespace

