/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Interface for authenticating a user at the client, and
 * tracking/controling resource usage.
 *
 * $Id: ClientAuthenticator.cs,v 1.1 2008/07/25 15:22:37 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Collections;

	public class ClientAuthenticator : Authenticator {

		// Construction
		public ClientAuthenticator(Globals glob) : base(glob)
		{
			m_glob.DPRINTV("ClientAuthenticator::ClientAuthenticator()");

			// Create initial user
			string initialUser = m_defaultAuthSettings.getUser();
			m_users[initialUser] = createUser(initialUser, true);
		}


		/*************/
		/* Accessors */
		/*************/

		// Get copy of current user details
		public override User getUserDetails(string name)
		{
			lock(this) {
				// Lookup user in cached details
				User user = getUser(name);
				if(user != null) {
					return (User)user.Clone();
				}

				// Return blank authenticated user details
				User blankUser = new User(m_glob);
				return blankUser;
			}
		}

		// Get whether user is authenticated for some tunnel
		public override bool getUserAuthenticated(string name, Tunnel tun)
		{
			// Always authenticated at the client
			return true;
		}


		/************/
		/* Mutators */
		/************/

		// Set the username & passwd we use to authenticate at the server
		public void setUserPasswd(string username, string passwd)
		{
			lock(this) {
				// This username becomes our default
				m_defaultUserName = username;
				m_defaultAuthSettings.setUserPasswd(username, passwd);

				// Create this user with default settings
				m_users[username] = createUser(username, false);
			}
		}


		/***********************/
		/* Protected Interface */
		/***********************/

		/***********/
		/* Methods */
		/***********/

		// Create a new tunnel user
		protected override User createUser(string name, bool keepCached)
		{
			// Create user already authenticated, with unlimited quotas
			Quotas quotas = new Quotas();
			User user = new User(m_glob, true, name, "", quotas, keepCached);
			return user;
		}

	}

}	// namespace

