/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various parameters to be used by a ClientTunnel when tunneling.
 *
 * $Id: ClientTunnelParms.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class ClientTunnelParms : TunnelParms {

		// Construction
		public ClientTunnelParms(Tunnel.TunnelTestState testState, uint urlPayloadSize,
		uint bodyPayloadSize) : base(testState)
		{
			m_urlPayloadSize = urlPayloadSize;
			m_bodyPayloadSize = bodyPayloadSize;
		}

		public ClientTunnelParms(ClientTunnelParms that) : base(that)
		{
			m_urlPayloadSize = that.m_urlPayloadSize;
			m_bodyPayloadSize = that.m_bodyPayloadSize;
		}


		/*************/
		/* Accessors */
		/*************/

		// Get maximum payload size for the specified mode
		public override uint getMaxPayloadSize(bool useHeader)
		{
			// Which mode?
			if(useHeader) {
				return getBodyPayloadSize();
			}
			else {
				return getURLPayloadSize();
			}
		}

		// Get URL payload size
		public uint getURLPayloadSize()
		{
			return m_urlPayloadSize;
		}

		// Get body payload size
		public uint getBodyPayloadSize()
		{
			return m_bodyPayloadSize;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Tunnel payload sizes
		protected uint								m_urlPayloadSize;
		protected uint								m_bodyPayloadSize;

	}

}	// namespace

