/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to record the result of a connect attempt.
 *
 * $Id: ConnectResultEvent.cs,v 1.2 2013/02/17 10:52:29 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;

	public class ConnectResultEvent : Event {

		/*********/
		/* Types */
		/*********/

		// Connect error types
		public enum ConnectResultType { GENERAL_ERROR = 0, FIREWALLED, ASYNC, SUCCESS }


		/***********/
		/* Methods */
		/***********/

		// Construction
		public ConnectResultEvent(Globals glob, Tunneler tunneler, uint connID,
		IPAddr addr, Enums.Protocol prot, bool ssl, ConnectResultType type)
		: base(glob)
		{
			m_tunneler = tunneler;
			m_connID = connID;
			m_addr = addr;
			m_protocol = prot;
			m_ssl = ssl;
			m_type = type;
		}


		// Report the error
		public override void execute()
		{
			m_glob.DPRINTV("ConnectResultEvent::execute()");

			// Let controlling tunneler know
			m_tunneler.connectResult(this);
		}


		/*************/
		/* Accessors */
		/*************/

		// Get connection result is for
		public uint getConnectionID()
		{
			return m_connID;
		}

		// Get address connect was to
		public IPAddr getAddr()
		{
			return m_addr;
		}

		// Get protocol connect used
		public Enums.Protocol getProtocol()
		{
			return m_protocol;
		}

		// Get whether connect used SSL
		public bool getSSL()
		{
			return m_ssl;
		}

		// Get connect error type
		public ConnectResultType getType()
		{
			return m_type;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Reference to controlling tunneler
		protected Tunneler						m_tunneler;

		// ID of connection error is from
		protected uint								m_connID;

		// Host/port/protocol connect was to
		protected IPAddr							m_addr;
		protected Enums.Protocol				m_protocol;
		protected bool								m_ssl;

		// Connection error type
		protected ConnectResultType			m_type;

	}

}  // namespace


