/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to record a fatal error on some connection.
 *
 * $Id: ConnectionErrorEvent.cs,v 1.2 2009/04/24 15:36:58 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Collections;

	public class ConnectionErrorEvent : Event, IdentifyEvent<uint> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(uint that)
		{
			return (m_connID == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public ConnectionErrorEvent(Globals glob, uint connID,
		Tunnel.TunnelErrorType type, Tunneler tunneler) : base(glob)
		{
			m_connID = connID;
			m_errors = new ArrayList();
			m_tunneler = tunneler;

			// Add initial error to list
			m_errors.Add(type);
		}

		// Run this event
		public override void execute()
		{
			m_glob.DPRINTV("ConnectionErrorEvent::execute()");

			lock(this) {
				// Let connections controlling tunneler know
				m_tunneler.connectionErrors(m_connID, m_errors);
			}
		}


		// Add new error to list
		public void addError(Tunnel.TunnelErrorType type)
		{
			lock(this) {
				// Filter out duplicates
				if(!m_errors.Contains(type))
					m_errors.Add(type);
			}
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// ID of connection error is from
		protected uint						m_connID;

		// The errors to report
		protected ArrayList				m_errors;

		// Controlling tunneler
		protected Tunneler				m_tunneler;

	}

}  // namespace


