/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Default user authentication at server; always authenticates.
 *
 * $Id: DefaultServerAuthenticator.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Collections;

	public class DefaultServerAuthenticator : ServerAuthenticator {

		// Construction
		public DefaultServerAuthenticator(Globals glob) : base(glob)
		{
			m_glob.DPRINTV("DefaultServerAuthenticator::DefaultServerAuthenticator()");

			// Create initial user
			string initialUser = m_defaultAuthSettings.getUser();
			m_users[initialUser] = createUser(initialUser, true);
		}


		/*************/
		/* Accessors */
		/*************/

		// Get copy of current user details
		public override User getUserDetails(string name)
		{
			lock(this) {
				// Lookup user in cached details
				User user = getUser(name);
				if(user != null) {
					return (User)user.Clone();
				}

				// Return blank authenticated user details
				User blankUser = new User(m_glob);
				return blankUser;
			}
		}


		/*************/
		/* Utilities */
		/*************/

		// Authenticate a new user
		public override void authenticate(string userName, Tunnel tun,
		ArrayList authArgs)
		{
			m_glob.DPRINTV("DefaultServerAuthenticator::authenticate()");

			lock(this) {
				// Let base class cache this user name
				base.authenticate(userName, tun, authArgs);

				// Authenticate user and let them know about their new tunnel
				User user = getUser(userName);
				user.setAuthenticated(true, tun);
				user.addTunnel(tun, true);
			}
		}


	}

}	// namespace

