/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Handle dummy reading/writing for one end of a raw tunnel
 * connection.
 *
 * $Id: DummyRawConnection.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class DummyRawConnection : RawConnection {

		// Construction
		public DummyRawConnection(Globals glob, Tunneler tunneler, TunnelID tid)
		: base(glob, tunneler, tid)
		{
			#if DEBUG_TUN
			StringBuilder dbg = new StringBuilder();
			dbg.AppendFormat("DummyRawConnection::DummyRawConnection() - connection {0}", getID());
			m_glob.DPRINTV(dbg.ToString());
			#endif

			// Construct reader/writer and become connected
			createReaderWriter();
		}


		// We are no longer required
		public override void destroyed()
		{
			#if DEBUG_TUN
			StringBuilder dbg = new StringBuilder();
			dbg.AppendFormat("DummyRawConnection::~DummyRawConnection() - connection {0}", getID());
			m_glob.DPRINTV(dbg.ToString());
			#endif

			// Base class
			base.destroyed();
		}


		/*************/
		/* Utilities */
		/*************/

		// Dummy reading
		public override void read()
		{
			// Do nothing
		}

		// Dummy writing
		public override void write(MsgParms parms)
		{
			// Do nothing
		}


	}

}	// namespace

