/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Base class of a TCP/IP socket server to listen for incoming
 * connections.
 *
 * $Id: Event.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;

	abstract public class Event : IComparable {

		/*************************/
		/* IComparable Interface */
		/*************************/

		// Compare timed events
		public int CompareTo(Object that)
		{
			// Compare event run times
			Event evnt = (Event)that;
			return (getRunTime().CompareTo(evnt.getRunTime()));
		}

		// Operators
		public static bool operator<(Event e1, Event e2)
		{
			return (e1.CompareTo(e2) < 0);
		}
		public static bool operator>(Event e1, Event e2)
		{
			return (e1.CompareTo(e2) > 0);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public Event(Globals glob)
		{
			m_glob = glob;
			m_runTime = Time.now();
		}

		public Event(Globals glob, Time runTime)
		{
			m_glob = glob;
			m_runTime = runTime;
		}


		// Get time to run at
		public Time getRunTime()
		{
			return m_runTime;
		}

		// Set time to run at
		public void setRunTime(Time runTime)
		{
			m_runTime = runTime;
		}


		// Run this event
		abstract public void execute();


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Reference to the globals
		protected Globals					m_glob;

		// Scheduled run time
		protected Time						m_runTime;

	}

}	// namespace


