/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate global configuration settings in a handy blob.
 *
 * $Id: GlobalConfigBlob.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

   public class GlobalConfigBlob : ConfigBlob {

		// Construction/destruction
		public GlobalConfigBlob() : base()
		{
			m_debug = Globals.ERROR;
			m_showLog = false;
		}

		public GlobalConfigBlob(uint debug) : base()
		{
			m_debug = debug;
			m_showLog = false;

			if(m_debug > Globals.VERBOSE)
				m_debug = Globals.VERBOSE;
		}


		/********************/
		/* Public Interface */
		/********************/


		/*************/
		/* Accessors */
		/*************/

		// Get blob type
		public override string getType()
		{
			return "GLOBAL";
		}

		// Get blob config as a parsable stream
		public override string getConfig()
		{
			StringBuilder cfg = new StringBuilder();

			// Format ourselves
			cfg.AppendLine("debug " + m_debug);
			cfg.AppendLine("nodaemon");
			if(m_showLog)
				cfg.AppendLine("showlog");

			return cfg.ToString();
		}


		/************/
		/* Mutators */
		/************/

		// Set debug level
		public void setDebug(uint debug)
		{
			m_debug = debug;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Debug level
		protected uint					m_debug;

		// Show log window
		protected bool					m_showLog;

	}

}	// namespace

