/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate parameters for an HTTP message.
 *
 * $Id: HTTPMsgParms.cs,v 1.2 2008/08/07 20:30:29 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	using System;
	using System.Collections;

	public class HTTPMsgParms : MsgParms {

		// Construction
		public HTTPMsgParms(Globals glob) : base(glob)
		{
			m_state = Tunnel.TunnelState.UNKNOWNSTATE;
			m_testState = Tunnel.TunnelTestState.NO_TESTING;
			m_ver = "1.1";
			m_ack = "";
			m_tunDest = "";
			m_useHeaderFields = true;
			m_proxyCfg = null;
			m_serverAuthCfg = null;
			m_user = new User(m_glob);
			m_quotas = new Quotas();
			m_respCode = 200;
			m_respPhrase = "OK";
			m_uri = "";
			m_cliVer = "";
			m_tune = "";
			m_tunnel = null;
			m_connClose = false;
			m_connKeepAlive = false;
			m_proxyConnClose = false;
			m_proxyConnKeepAlive = false;
			m_notifs = new ArrayList();
		}

		public HTTPMsgParms(Globals glob, Tunnel tunnel, Payload payload, bool retry,
		User user, Tunnel.TunnelState state, string ver, string acks, string tunDest,
		bool useHeader) : base(glob, tunnel.getTidStr(), payload, retry)
		{
			m_state = state;
			m_testState = tunnel.getTestState();
			m_ver = ver;
			m_ack = acks;
			m_tunDest = tunDest;
			m_useHeaderFields = useHeader;
			m_proxyCfg = tunnel.getProxySettings();
			m_serverAuthCfg = tunnel.getServerAuthSettings();
			m_user = user;
			m_quotas = user.getQuotas();
			m_respCode = 200;
			m_respPhrase = "OK";
			m_uri = "";
			m_cliVer = "";
			m_tune = "";
			m_tunnel = tunnel;
			m_connClose = false;
			m_connKeepAlive = false;
			m_proxyConnClose = false;
			m_proxyConnKeepAlive = false;
			m_notifs = tunnel.getSendNotifMsgs();
		}

		public HTTPMsgParms(HTTPMsgParms that) : base(that)
		{
			m_state = that.m_state;
			m_testState = that.m_testState;
			m_ver = that.m_ver;
			m_ack = that.m_ack;
			m_tunDest = that.m_tunDest;
			m_useHeaderFields = that.m_useHeaderFields;
			m_proxyCfg = that.m_proxyCfg;
			m_serverAuthCfg = that.m_serverAuthCfg;
			m_user = that.m_user;
			m_quotas = that.m_quotas;
			m_respCode = that.m_respCode;
			m_respPhrase = that.m_respPhrase;
			m_uri = that.m_uri;
			m_cliVer = that.m_cliVer;
			m_tune = that.m_tune;
			m_tunnel = that.m_tunnel;
			m_connClose = that.m_connClose;
			m_connKeepAlive = that.m_connKeepAlive;
			m_proxyConnClose = that.m_proxyConnClose;
			m_proxyConnKeepAlive = that.m_proxyConnKeepAlive;
			m_notifs = that.m_notifs;
		}


		/*************/
		/* Accessors */
		/*************/

		// Get HTTP connection state
		public Tunnel.TunnelState getState()
		{
			return m_state;
		}

		// Get tunnel testing state
		public Tunnel.TunnelTestState getTestState()
		{
			return m_testState;
		}

		// Get HTTP version
		public string getVer()
		{
			return m_ver;
		}

		// Get ack
		public string getAck()
		{
			return m_ack;
		}

		// Get tunnel destination address
		public string getTunDest()
		{
			return m_tunDest;
		}

		// Get whether we are using header fields for tunneling
		public bool getUseHeaderFields()
		{
			return m_useHeaderFields;
		}

		// Get tunnels proxy config
		public ProxySettings getProxySettings()
		{
			return m_proxyCfg;
		}

		// Get tunnels serverauth config
		public ServerAuthSettings getServerAuthSettings()
		{
			return m_serverAuthCfg;
		}

		// Get user msg is for
		public User getUser()
		{
			return m_user;
		}

		// Get quotas for user
		public Quotas getQuotas()
		{
			return m_quotas;
		}

		// Get response code
		public ushort getRespCode()
		{
			return m_respCode;
		}

		// Get response phrase
		public string getRespPhrase()
		{
			return m_respPhrase;
		}

		// Get URI
		public string getURI()
		{
			return m_uri;
		}

		// Get client version identifier
		public string getCliVer()
		{
			return m_cliVer;
		}

		// Get tunnel tuning settings
		public string getTunTune()
		{
			return m_tune;
		}

		// Get whether user is authenticated for this msgs tunnel
		public bool getUserAuthenticated()
		{
			return m_user.getAuthenticated(m_tunnel);
		}

		// Get whether we saw a Connection close option
		public bool getConnClose()
		{
			return m_connClose;
		}

		// Get whether we saw a Connection keep-alive option
		public bool getConnKeepAlive()
		{
			return m_connKeepAlive;
		}

		// Get whether we saw a Proxy-Connection close option
		public bool getProxyConnClose()
		{
			return m_proxyConnClose;
		}

		// Get whether we saw a Proxy-Connection keep-alive option
		public bool getProxyConnKeepAlive()
		{
			return m_proxyConnKeepAlive;
		}

		// Get notification msgs
		public ArrayList getNotifs()
		{
			return (ArrayList)m_notifs.Clone();
		}


		/************/
		/* Mutators */
		/************/

		// Set HTTP connection state
		public void setState(Tunnel.TunnelState state)
		{
			m_state = state;
		}

		// Set tunnel testing state
		public void setTestState(Tunnel.TunnelTestState testState)
		{
			m_testState = testState;
		}

		// Set HTTP version
		public void setVer(string ver)
		{
			m_ver = ver;
		}

		// Set ack
		public void setAck(string ack)
		{
			m_ack = ack;
		}

		// Set tunnel destination address
		public void setTunDest(string dest)
		{
			m_tunDest = dest;
		}

		// Set whether we are using header fields for tunneling
		public void setUseHeaderFields(bool uh)
		{
			m_useHeaderFields = uh;
		}

		// Set response code & phrase
		public void setRespCodePhrase(ushort code, string phrase)
		{
			m_respCode = code;
			m_respPhrase = phrase;
		}

		// Set URI
		public void setURI(string uri)
		{
			m_uri = uri;
		}

		// Set proxy settings
		public void setProxySettings(ProxySettings settings)
		{
			m_proxyCfg = settings;
		}

		// Set server auth settings
		public void setServerAuthSettings(ServerAuthSettings settings)
		{
			m_serverAuthCfg = settings;
		}

		// Set user
		public void setUser(User user)
		{
			m_user = user;
		}

		// Set users quotas
		public void setQuotas(Quotas quotas)
		{
			m_quotas = quotas;
		}

		// Set client version identifier
		public void setCliVer(string cliVer)
		{
			m_cliVer = cliVer;
		}

		// Set tunnel tunable settings
		public void setTunTune(string tune)
		{
			m_tune = tune;
		}

		// Set Connection option seen
		public void setConnOption(string opt)
		{
			if(opt == "close" || opt == "Close") {
				m_connClose = true;
			}
			else if(opt == "keep-alive" || opt == "Keep-Alive") {
				m_connKeepAlive = true;
			}
		}

		// Set Proxy-Connection option seen
		public void setProxyConnOption(string opt)
		{
			if(opt == "close" || opt == "Close") {
				m_proxyConnClose = true;
			}
			else if(opt == "keep-alive" || opt == "Keep-Alive") {
				m_proxyConnKeepAlive = true;
			}
		}

		// Set notification msgs
		public void setNotifs(ArrayList msgs)
		{
			m_notifs = (ArrayList)msgs.Clone();
		}

		// Add a notification msg
		public void addNotif(string msg)
		{
			m_notifs.Add(msg);
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Connection states for tunnel
		protected Tunnel.TunnelState			m_state;
		protected Tunnel.TunnelTestState		m_testState;

		// HTTP version
		protected string							m_ver;

		// List of msg acks
		protected string							m_ack;

		// Tunnel destination address
		protected string							m_tunDest;

		// Using header fields for tunneling?
		protected bool								m_useHeaderFields;

		// Tunnel proxy & serverauth settings
		protected ProxySettings					m_proxyCfg;
		protected ServerAuthSettings			m_serverAuthCfg;

		// User msg is for
		protected User								m_user;
		protected Quotas							m_quotas;

		// Code & phrase for response msgs
		protected ushort							m_respCode;
		protected string							m_respPhrase;

		// Requested URI (either for sending or repsonding to)
		protected string							m_uri;

		// Client version identifier
		protected string							m_cliVer;

		// Tunnel tuning
		protected string							m_tune;

		// Tunnel msg is for
		protected Tunnel							m_tunnel;

		// Connection options
		protected bool								m_connClose;
		protected bool								m_connKeepAlive;
		protected bool								m_proxyConnClose;
		protected bool								m_proxyConnKeepAlive;

		// List of notification msgs
		protected ArrayList						m_notifs;

	}

}	// namespace

