/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating a new HTTP msg has arrived.
 *
 * $Id: MsgArrivedEvent.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class MsgArrivedEvent : Event {

		// Construction
		public MsgArrivedEvent(Globals glob, uint connID, Tunneler tunneler,
		HTTPMsg msg) : base(glob)
		{
			m_connID = connID;
			m_tunneler = tunneler;
			m_msg = msg;
		}

		// Run this event
		public override void execute()
		{
			m_glob.DPRINTV("MsgArrivedEvent::execute()");

			try {
				// Let connections controlling tunneler know
				m_tunneler.messageArrived(m_connID, m_msg);
			}
			catch(LookupManagementError e) {
				m_glob.log().warn("Failed to process message arrival event: " + e.Message);
			}
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// ID of connection error is from
		protected uint							m_connID;

		// Controlling tunneler
		protected Tunneler					m_tunneler;

		// The message itself
		protected HTTPMsg						m_msg;

	}

}  // namespace


