/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to indicate a poll timeout on a tunnel.
 *
 * $Id: PollTimeoutEvent.cs,v 1.2 2013/03/24 09:55:58 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class PollTimeoutEvent : TimedEvent, IdentifyEvent<TunnelID> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(TunnelID that)
		{
			return (m_tid == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public PollTimeoutEvent(Globals glob, Time time, Tunneler tunneler,
		TunnelID tid) : base(glob, time)
		{
			m_tunneler = tunneler;
			m_tid = tid;
		}

		// Run this event
		public override void execute()
		{
			// Let tunneler know
			m_tunneler.pollTimeout(m_tid);
		}

public TunnelID getTID()
{
	return m_tid;
}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Tunnel ID
		protected TunnelID					m_tid;

		// Controlling tunneler
		protected Tunneler					m_tunneler;

	}

}  // namespace


