/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate settings for tunneling through a proxy.
 *
 * $Id: ProxySettings.cs,v 1.2 2013/02/17 10:52:30 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class ProxySettings : AuthSettings, ICloneable {

		// Construction
		public ProxySettings(Globals glob, string user, string domain, string passwd,
		IPAddr proxyIP) : base(glob, user, domain, passwd)
		{
			m_IP = proxyIP;
		}

		protected ProxySettings(ProxySettings that) : base(that)
		{
			m_IP = that.m_IP;
		}

		// Clone
		public object Clone()
		{
			ProxySettings clone = new ProxySettings(this);
			return clone;
		}


		/*************/
		/* Accessors */
		/*************/

		// Get proxy IP
		public IPAddr getIP()
		{
			return m_IP;
		}


		/*************/
		/* Utilities */
		/*************/

		// Construct tunneling proxy headers
		public override string getRequestHeader(string uri)
		{
			StringBuilder res = new StringBuilder();

			// General proxy fields
			res.Append("Proxy-Connection: keep-alive\r\n");

			// Proxy authentication fields
			res.Append(base.getRequestHeader(uri));

			return res.ToString();
		}


		// Clear and reset any exisiting authentication scheme details
		public override void reset()
		{
			if(m_authScheme != AuthScheme.AUTH_HOLD) {
				// Can we short-circuit request header creation?
				if(m_authScheme == AuthScheme.AUTH_BASIC) {
					// Hold current auth scheme
					m_authScheme = AuthScheme.AUTH_HOLD;
				}
				else if(m_authScheme == AuthScheme.AUTH_NTLM) {
					// It seems we don't need to keep sending the NTLM request header
					m_authScheme = AuthScheme.AUTH_NONE;
					m_ntlmHandler.reset();
				}

				// Clear tried schemes
				m_triedSchemes.Clear();
			}
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/***********/
		/* Methods */
		/***********/

		// Get authorisation request header field identifier
		protected override string getAuthRequestHeaderID()
		{
			return "Proxy-Authorization";
		}


		/********/
		/* Data */
		/********/

		// Proxy IP address
		protected IPAddr					m_IP;

	}

}	// namespace

