/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate quotas for a tunnel.
 *
 * $Id: Quotas.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class Quotas : ICloneable {

		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public Quotas()
		{
			m_bandwidth = 0;
			m_noTunnels = 0;
		}

		public Quotas(uint bandwidth, uint noTunnels)
		{
			m_bandwidth = bandwidth;
			m_noTunnels = noTunnels;
		}

		public Quotas(string qstr)
		{
			m_bandwidth = 0;
			m_noTunnels = 0;

			// Parse quotas from string
			char[] sep = new char[]{','};
			string[] parts = qstr.Split(sep);
			if(parts.Length > 0) {
				if(parts.Length >= 1) {
					// Got bandwidth quota
					m_bandwidth = uint.Parse(parts[0]);
				}
				if(parts.Length >= 2) {
					// Got max number of tunnels quota
					m_noTunnels = uint.Parse(parts[1]);
				}
			}
		}

		// Clone
		public object Clone()
		{
			return this.MemberwiseClone();
		}


		// Operators
		public static bool operator==(Quotas q1, Quotas q2)
		{
			return (q1.Equals(q2));
		}
		public static bool operator!=(Quotas q1, Quotas q2)
		{
			return !(q1.Equals(q2));
		}

		// As recommended, also override Equals() & GetHashCode()
		public override bool Equals(object that)
		{
			bool res = false;
			if(that != null && that is Quotas) {
				Quotas quo = (Quotas)that;
				res = (
					getBandwidth() == quo.getBandwidth() &&
					getNoTunnels() == quo.getNoTunnels()
				);
			}

			return res;
		}
		public override int GetHashCode()
		{
			return ToString().GetHashCode();
		}

		// Create a representation of ourselves as a string
		public override string ToString()
		{
			StringBuilder str = new StringBuilder();
			str.AppendFormat("{0},{1}", getBandwidth(), getNoTunnels());
			return str.ToString();
		}


		/*************/
		/* Accessors */
		/*************/

		// Get bandwidth limit
		public uint getBandwidth()
		{
			return m_bandwidth;
		}

		// Get number of tunnels limit
		public uint getNoTunnels()
		{
			return m_noTunnels;
		}


		/************/
		/* Mutators */
		/************/

		// Set bandwidth limit
		public void setBandwidth(uint bandwidth)
		{
			m_bandwidth = bandwidth;
		}

		// Set number of tunnels limit
		public void setNoTunnels(uint noTunnels)
		{
			m_noTunnels = noTunnels;
		}


		/*********************/
		/* Private Interface */
		/*********************/


		/********/
		/* Data */
		/********/

		// The quotas we track
		private uint				m_bandwidth;
		private uint				m_noTunnels;

	}

}  // namespace

