/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating some new raw data has arrived.
 *
 * $Id: RawDataArrivedEvent.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class RawDataArrivedEvent : Event, IdentifyEvent<uint> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(uint that)
		{
			return (m_connID == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public RawDataArrivedEvent(Globals glob, uint connID, TunnelID tid,
		Tunneler tunneler, byte[] data, uint length) : base(glob)
		{
			m_connID = connID;
			m_tid = tid;
			m_tunneler = tunneler;
			m_raw = new RawBuff(data, length);
		}

		// Run this event
		public override void execute()
		{
			try {
				// Let connections controlling tunneler know
				m_tunneler.rawDataArrived(m_connID, m_tid, m_raw);
			}
			catch(LookupManagementError e) {
				m_glob.log().warn("Failed to process raw data arrival event: " + e.Message);
			}
		}

		// Get the raw data
		public RawBuff getRaw()
		{
			return m_raw;
		}

		// More new data
		public void moreData(byte[] data, uint length)
		{
			m_raw.append(data, length);
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// ID of connection error is from
		protected uint						m_connID;

		// ID of tunnel data is from
		protected TunnelID				m_tid;

		// Controlling tunneler
		protected Tunneler				m_tunneler;

		// The data itself
		RawBuff								m_raw;

	}

}  // namespace


