/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A raw data reader.
 *
 * $Id: RawReader.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class RawReader : Reader {

		// Construction
		public RawReader(Globals glob, Connection conn, TunnelID tid)
		: base(glob, conn)
		{
			m_glob.DPRINTV("RawReader::RawReader()");
			m_tid = tid;
		}

		public RawReader(Globals glob, Connection conn)
		: base(glob, conn)
		{
			m_glob.DPRINTV("RawReader::RawReader()");
			m_tid = new TunnelID();
		}


		/********************/
		/* Public Interface */
		/********************/


		// Set the tunnel ID we work for
		public void setTunnelID(TunnelID tid)
		{
			lock(this) {
				m_tid = tid;
			}
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/***********/
		/* Methods */
		/***********/

		// Process some newly read raw data
		protected override void processData(byte[] data, uint length)
		{
			#if DEBUG_LOG_DATA
			// Log read data
			RawBuff buff = new RawBuff(data, length);
			m_glob.logRawRead(buff);
			#endif

			// See if we have a raw payload event we can replace
			Tunneler tunneler = m_conn.getTunneler();
			uint connID = m_conn.getID();
			RawDataArrivedEvent evnt = tunneler.cancelAndGetEvent<RawDataArrivedEvent, uint>(connID);
			if(evnt != null) {
				// Add data to this event
				evnt.moreData(data, length);
			}
			else {
				// Create new raw payload arrival event
				evnt = new RawDataArrivedEvent(m_glob, connID, m_tid, tunneler, data, length);
			}

			// Schedule raw payload arrival event
			tunneler.scheduleEvent(evnt);
		}


		/********/
		/* Data */
		/********/

		// ID of tunnel we work for
		protected TunnelID					m_tid;

	}

}	// namespace

