/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A raw data writer.
 *
 * $Id: RawWriter.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class RawWriter : Writer {

		// Construction
		public RawWriter(Globals glob, Connection conn) : base(glob, conn)
		{
			m_glob.DPRINTV("RawWriter::RawWriter()");
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/***********/
		/* Methods */
		/***********/

		// Attempt to process some data to send out
		protected override void processData(MsgParms parms, RawBuff dest)
		{
			// Get data to process
			RawBuff src = parms.getPayload().getPayload();
			if(src.getLength() > 0) {
				#if DEBUG_TUN
				StringBuilder nfo = new StringBuilder();
				nfo.AppendFormat("RawWriter::processData() - Got {0} bytes", src.getLength());
				m_glob.DPRINTV(nfo.ToString());
				#endif

				#if DEBUG_LOG_DATA
				// Log data
				m_glob.logRawWrite(src);
				#endif

				// Just append data from in to out
				dest.append(src);
			}
			#if DEBUG_TUN
			else {
				m_glob.DPRINTV("RawWriter::processData() - Ignoring 0 length data");
			}
			#endif
		}

	}

}	// namespace

