/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Base class for data readers.
 *
 * $Id: Reader.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public abstract class Reader {

		// Construction
		public Reader(Globals glob, Connection conn)
		{
			m_glob = glob;
			m_conn = conn;
			m_readbuff = new byte[READ_BUF_SIZE];
		}


		/********************/
		/* Public Interface */
		/********************/

		// Read and process some data from our socket
		public virtual void read()
		{
			lock(this) {
				try {
					// Read data from socket
					Sock sock = m_conn.getSocket();
					int noread = sock.read(m_readbuff);

					// Try to process what we currently have buffered
					processData(m_readbuff, (uint)noread);
				}
				catch(SockError e) {
					StringBuilder dbg = new StringBuilder();
					dbg.AppendFormat("Error reading from socket for connection {0}: {1} - {2}",
						m_conn.getID(), e.m_errno.ToString(), e.Message);
					throw new ReadError(dbg.ToString());
				}
			}
		}


		/*************/
		/* Accessors */
		/*************/

		// Do we have unprocessed data remaining?
		public virtual bool dataRemaining()
		{
			return false;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/***********/
		/* Methods */
		/***********/

		// Attempt to process some newly read data
		protected abstract void processData(byte[] data, uint length);


		/*************/
		/* Constants */
		/*************/

		// Size of socket read buffer
		protected const uint			READ_BUF_SIZE = 16384;


		/********/
		/* Data */
		/********/

		// Global data
		protected Globals				m_glob;

		// Our controlling connection
		protected Connection			m_conn;


		/*********************/
		/* Private Interface */
		/*********************/


		/********/
		/* Data */
		/********/

		// Our raw socket read buffer
		private byte[]					m_readbuff;

	}

}	// namespace

