/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to request a send of a HTTP message for some tunnel.
 *
 * $Id: SendMsgEvent.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class SendMsgEvent : TimedEvent, IdentifyEvent<uint> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(uint that)
		{
			return (m_connID == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public SendMsgEvent(Globals glob, Time time, uint connID, bool retry,
		TunnelID tid, Tunneler tunneler) : base(glob, time)
		{
			m_connID = connID;
			m_retry = retry;
			m_tid = tid;
			m_tunneler = tunneler;
		}

		// Run this event
		public override void execute()
		{
			m_glob.DPRINTV("SendMsgEvent::execute()");

			// Let connections controlling tunneler do the send
			m_tunneler.sendTunnelMsg(m_tid, m_connID, m_retry);
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// ID of connection to send msg down
		protected uint						m_connID;

		// Should we retry if sending fails?
		protected bool						m_retry;

		// ID of tunnel to send msg down
		protected TunnelID				m_tid;

		// Controlling tunneler
		protected Tunneler				m_tunneler;

	}

}  // namespace


