/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a payload sequence number.
 *
 * $Id: SeqNo.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel {

	using System;

	public class SeqNo : IComparable {

		/*************************/
		/* IComparable Interface */
		/*************************/

		// Compare based on value
		public int CompareTo(Object that)
		{
			int res = 0;
			SeqNo seqNo = (SeqNo)that;

			// Not equal?
			if(getVal() != seqNo.getVal()) {
				// Less than?
				if(lessThan(seqNo))
					res = -1;
				else
					res = 1;
			}

			return res;
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public SeqNo()
		{
			m_val = 0;
		}

		public SeqNo(uint val)
		{
			m_val = val;
		}

		public SeqNo(SeqNo that)
		{
			m_val = that.m_val;
		}


		// Create a representation of ourselves as a string
		public override string ToString()
		{
			return getVal().ToString();
		}

		// Operators
		public static bool operator==(SeqNo s1, SeqNo s2)
		{
			return (s1.Equals(s2));
		}
		public static bool operator!=(SeqNo s1, SeqNo s2)
		{
			return !(s1.Equals(s2));
		}
		public static bool operator<(SeqNo s1, SeqNo s2)
		{
			return (s1.CompareTo(s2) < 0);
		}
		public static bool operator>(SeqNo s1, SeqNo s2)
		{
			return (s1.CompareTo(s2) > 0);
		}
		public static bool operator>=(SeqNo s1, SeqNo s2)
		{
			return (s1.CompareTo(s2) >= 0);
		}
		public static bool operator<=(SeqNo s1, SeqNo s2)
		{
			return (s1.CompareTo(s2) <= 0);
		}

		// As recommended, also override Equals() & GetHashCode()
		public override bool Equals(object that)
		{
			bool res = false;
			if(that != null && that is SeqNo) {
				SeqNo sn = (SeqNo)that;
				res = (getVal() == sn.getVal());
			}

			return res;
		}
		public override int GetHashCode()
		{
			return ToString().GetHashCode();
		}


		/*************/
		/* Accessors */
		/*************/

		// Get our raw value
		public uint getVal()
		{
			return m_val;
		}

		// Get highest sequence no we use
		public uint getMaxSeqNo()
		{
			return MAX_SEQ_NO;
		}


		/************/
		/* Mutators */
		/************/

		// Increment
		public void inc()
		{
			if(++m_val > MAX_SEQ_NO)
				m_val = 1;
		}


		/*********************/
		/* Private Interface */
		/*********************/

		/*************/
		/* Constants */
		/*************/

		// Value at which we roll-over
		private const uint				MAX_SEQ_NO		= 999;


		/***********/
		/* Methods */
		/***********/

		// Less than
		private bool lessThan(SeqNo that)
		{
			bool res = false;

			if(getVal() < that.getVal()) {
				// Have we wrapped?
				if((that.getVal() - getVal()) < (MAX_SEQ_NO / 2)) {
					res = true;
				}
			}
			else {
				// Have we wrapped?
				if((getVal() - that.getVal()) > (MAX_SEQ_NO / 2)) {
					res = true;
				}
			}

			return res;
		}


		/********/
		/* Data */
		/********/

		// Our current value
		private uint				m_val;

	}

}	// namespace

