/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate server tunnel configuration settings in a handy blob.
 *
 * $Id: ServerConfigBlob.cs,v 1.3 2013/03/03 10:06:00 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class ServerConfigBlob : ConfigBlob {

		// Construction/destruction
		public ServerConfigBlob(string lhost, uint lport, AddrInfo.Family lfam,
		bool auth) : base()
		{
			m_listenIP = new IPAddr(lhost, lport, lfam);
			m_auth = auth;
			m_ssl = false;
			m_cert = "";
			m_certKey = "";
		}

		public ServerConfigBlob(string lhost, uint lport, AddrInfo.Family lfam,
		bool auth, string cert, string certKey) : base()
		{
			m_listenIP = new IPAddr(lhost, lport, lfam);
			m_auth = auth;
			m_ssl = true;
			m_cert = cert;
			m_certKey = certKey;
		}


		/********************/
		/* Public Interface */
		/********************/


		/*************/
		/* Accessors */
		/*************/

		// Get blob type
		public override string getType()
		{
			return "SERVER";
		}

		// Get blob config as a parsable stream
		public override string getConfig()
		{
			StringBuilder cfg = new StringBuilder();

			/* Format ourselves */

			// Local server listen address
			cfg.Append("listen ");
			string lhost = m_listenIP.getHost();
			if(lhost.Length > 0)
				cfg.AppendLine(lhost + " " + m_listenIP.getPort().ToString());
			else
				cfg.AppendLine(m_listenIP.getPort().ToString() + " " + m_listenIP.getFamilyStr());

			// Server authentication
			if(m_auth)
				cfg.AppendLine("svrauth");

			// SSL certificate & key
			if(m_ssl)
				cfg.AppendLine("ssl " + m_cert + " " + m_certKey);

			// Firewall settings

			return cfg.ToString();
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Local listening address
		protected IPAddr				m_listenIP;

		// Require clients to authenticate?
		protected bool					m_auth;

		// SSL settings
		protected bool					m_ssl;
		protected string				m_cert;
		protected string				m_certKey;

	}

}	// namespace

