/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Server side socket server.
 *
 * $Id: ServerServer.cs,v 1.2 2008/11/21 18:39:42 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;
	using System.Threading;

	public class ServerServer : Server {

		// Construction
		public ServerServer(Globals glob, ServerSideConfig serverConfig)
		: base(glob, serverConfig)
		{
			m_glob.DPRINTV("ServerServer::ServerServer()");

			try {
				// Take mutexes
				Monitor.Enter(m_serverThreadStartMtx);

				// Setup server socket
				configureSocket(serverConfig.getSSL());

				// Create server tunneler
				string err = "";
				try {
					m_tunneler = new ServerTunneler(m_glob, this);
				}
				catch(TunnelError e) {
					// Error creating tunneler
					err = "Error creating server tunneler: " + e.Message;
				}

				// Wait for server thread to start
				Monitor.Wait(m_serverThreadStartMtx);
				Monitor.Exit(m_serverThreadStartMtx);

				// Let server thread proceed with accepting connections
				Monitor.Enter(m_serverThreadContMtx);
				Monitor.Pulse(m_serverThreadContMtx);
				Monitor.Exit(m_serverThreadContMtx);

				// If we had an error throw it now
				if(err.Length > 0) {
					throw new TunnelError(err);
				}
			}
			catch(TunnelError e) {
				// Clear up cleanly before passing up error
				destroyed();
				throw e;
			}
		}


		// Destruction
		public override void destroyed()
		{
			lock(this) {
			}

			// Base class
			base.destroyed();
		}


		/*************/
		/* Accessors */
		/*************/

		// Get status string
		public override string getStatusString()
		{
			StringBuilder status = new StringBuilder();
			status.AppendFormat("Server: {0}", base.getStatusString());
			return status.ToString();
		}

	}

}	// namespace

