/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all global configuration for
 * one side of a tunneler.
 *
 * $Id: SideConfig.cs,v 1.2 2013/02/17 10:53:19 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
   using System;
	using System.IO;
	using System.Text;

   public abstract class SideConfig {

		// Construction/destruction
		public SideConfig(Globals glob, Enums.Protocol prot, bool ssl, bool sockTun,
		IPAddr listenIP)
		{
			m_glob = glob;
			m_protocol = prot;
			m_ssl = ssl;
			m_sockTun = sockTun;
			m_listenIP = listenIP;
			m_tunnelerID = new TunnelerID(m_glob, this);
			m_authenticator = null;
			m_cfgError = false;
		}


		/********************/
		/* Public Interface */
		/********************/


		/*************/
		/* Accessors */
		/*************/

		// Get protocol to use for server
		public Enums.Protocol getProtocol()
		{
			return m_protocol;
		}

		// Get whether to use SSL
		public bool getSSL()
		{
			return m_ssl;
		}

		// Get whether we are for a socket tunneler
		public bool isSockTun()
		{
			return m_sockTun;
		}

		// Get listen address
		public IPAddr getListenIP()
		{
			return m_listenIP;
		}

		// Get full listen address
		public string getListenAddr()
		{
			StringBuilder addr = new StringBuilder();
			addr.AppendFormat("{0};{1}", m_listenIP.getHost(), m_listenIP.getPort());
			return addr.ToString();
		}

		// Get tunneler ID
		public TunnelerID getTunnelerID()
		{
			return m_tunnelerID;
		}

		// Client config?
		public virtual bool isClient()
		{
			return false;
		}

		// Server config?
		public virtual bool isServer()
		{
			return false;
		}

		// Get authenticator
		public virtual Authenticator getAuthenticator()
		{
			return m_authenticator;
		}

		// Error in config?
		public bool getErrored()
		{
			return m_cfgError;
		}


		/************/
		/* Mutators */
		/************/

		// Set listen address
		public void setListenIP(IPAddr lip)
		{
			m_listenIP = lip;
		}

		// Flag error in config
		public void setErrored(bool err)
		{
			m_cfgError = err;
		}


		/*************/
		/* Utilities */
		/*************/

		// Serialize to a file
		public abstract void serialize(StreamWriter file);


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Globals
		protected Globals					m_glob;

		// Protocol to use for server comms
		protected Enums.Protocol		m_protocol;
		protected bool						m_ssl;

		// Are we for a socket tunneler?
		protected bool						m_sockTun;

		// The local listening address details
		protected IPAddr					m_listenIP;

		// TunnelerID for this config
		protected TunnelerID				m_tunnelerID;

		// Authenticator
		protected Authenticator			m_authenticator;

		// Is there an error with this config?
		protected bool						m_cfgError;

	}

}	// namespace

