/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * A server to accept incoming socket tunnel connections.
 *
 * $Id: SockTunServer.cs,v 1.3 2013/02/17 10:53:19 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Net.Sockets;
	using System.Threading;

	public class SockTunServer {

		// Callback delegate
		public delegate void SockTunCallback(Sock sock);

		// Construction
		public SockTunServer(Globals glob, SockTunCallback userCallback)
		{
			m_glob = glob;
			m_sock = null;
			m_prot = Enums.Protocol.TCP;
			m_listenIP = new IPAddr("127.0.0.1", 0);
			m_userCallback = userCallback;
			m_thread = null;
			m_serverMtx = new Mutex();
			m_shutDownMtx = new Mutex();
			m_shutDown = false;

			m_glob.DPRINTV("SockTunServer::SockTunServer()");
		}

		// We are no longer required
		public virtual void destroyed()
		{
			m_glob.DPRINTV("SockTunServer::~SockTunServer()");

			lock(this) {
				// Socket destroyed
				if(m_sock != null) {
					m_sock.destroyed();
					m_sock = null;
				}
			}
		}


		/*************/
		/* Accessors */
		/*************/

		// Get address we are listening on
		public IPAddr getListenIP()
		{
			return m_listenIP;
		}

		// Get protocol we're using
		public Enums.Protocol getProtocol()
		{
			return m_prot;
		}


		/***********************/
		/* Protected interface */
		/***********************/


		/*************/
		/* Constants */
		/*************/

		// Timeout (in miliseconds) between poll()s
		protected const int				POLL_TIMEOUT		= 10;


		/***********/
		/* Methods */
		/***********/

		// Make callback to user
		protected void callbackToUser(Sock sock)
		{
			lock(this) {
				m_glob.DPRINTV("SockTunServer::callbackToUser() - Invoking user callback");

				// Do the callback
				m_userCallback(sock);
			}
		}


		/********/
		/* Data */
		/********/

		// Globals
		protected Globals					m_glob;

		// Socket to listen on
		protected Sock						m_sock;
		protected Enums.Protocol		m_prot;

		// Address we are listening on
		protected IPAddr					m_listenIP;

		// Callback to user
		protected SockTunCallback		m_userCallback;

		// Connection handling thread details
		protected Thread					m_thread;
		protected Mutex					m_serverMtx;
		protected Mutex					m_shutDownMtx;
		protected bool						m_shutDown;

	}

}	// namespace


