/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate server socket tunnel configuration settings in a handy
 * blob.
 *
 * $Id: SockTunServerConfigBlob.cs,v 1.2 2013/02/17 10:53:19 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class SockTunServerConfigBlob : ServerConfigBlob {

		// Construction/destruction
		public SockTunServerConfigBlob(string lhost, uint lport, AddrInfo.Family lfam,
		bool auth, SockTunServer.SockTunCallback userCallback)
		: base(lhost, lport, lfam, auth)
		{
			m_userCallback = userCallback;
		}

		public SockTunServerConfigBlob(string lhost, uint lport, AddrInfo.Family lfam,
		bool auth, string cert, string certKey, SockTunServer.SockTunCallback userCallback)
		: base(lhost, lport, lfam, auth, cert, certKey)
		{
			m_userCallback = userCallback;
		}


		/********************/
		/* Public Interface */
		/********************/


		/*************/
		/* Accessors */
		/*************/

		// Get blob config as a parsable stream
		public override string getConfig()
		{
			StringBuilder cfg = new StringBuilder();

			/* Format ourselves */

			// Socket based tunneling
			cfg.AppendLine("socktun");

			// Get base class formating
			cfg.Append(base.getConfig());

			return cfg.ToString();
		}

		// Get callback to user
		public SockTunServer.SockTunCallback getUserCallback()
		{
			return m_userCallback;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Callback to user
		protected SockTunServer.SockTunCallback	m_userCallback;

	}

}	// namespace

