/* (C) 2009 Richard Mills / The Linux Academy Ltd.
 *
 * An event to indicate a tunnel has been destroyed.
 *
 * $Id: TunnelDestroyedEvent.cs,v 1.1 2009/03/20 11:55:49 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;

	public class TunnelDestroyedEvent : Event, IdentifyEvent<TunnelID> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(TunnelID that)
		{
			return (m_tid == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public TunnelDestroyedEvent(Globals glob, Tunneler tunneler, TunnelID tid) : base(glob)
		{
			m_tunneler = tunneler;
			m_tid = tid;
		}

		// Run this event
		public override void execute()
		{
			m_glob.DPRINTV("TunnelDestroyedEvent::execute()");

			// Let tunnels controlling tunneler know
			m_tunneler.tunnelDestroyed(m_tid);
		}


		/***********************/
		/* Protected Interface */
		/***********************/

		/********/
		/* Data */
		/********/

		// Tunneler to invoke event for
		protected Tunneler				m_tunneler;

		// ID of tunnel message is for
		protected TunnelID				m_tid;

	}

}	// namespace

