/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various parameters to be used by a Tunnel when tunneling.
 *
 * $Id: TunnelParms.cs,v 1.2 2008/08/07 20:30:29 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public abstract class TunnelParms {

		// Construction
		public TunnelParms(Tunnel.TunnelTestState testState)
		{
			m_createTime = Time.now();
			m_testState = testState;
		}

		public TunnelParms(TunnelParms that)
		{
			m_createTime = that.m_createTime;
			m_testState = that.m_testState;
		}


		/*************/
		/* Accessors */
		/*************/

		// Get maximum payload size for the specified mode
		public abstract uint getMaxPayloadSize(bool useHeader);

		// Get time we were created
		public Time getCreateTime()
		{
			return m_createTime;
		}

		// Get test state when we were created
		public Tunnel.TunnelTestState getTestState()
		{
			return m_testState;
		}

		// Get whether we represent completed tests
		public bool testsCompleted()
		{
			return (getTestState() == Tunnel.TunnelTestState.COMPLETED_TESTING);
		}


		/************/
		/* Mutators */
		/************/

		// Reset to our initial testing state
		public void resetTestState()
		{
			m_testState = Tunnel.TunnelTestState.BEGIN_TESTING;
		}


		/***********************/
		/* Protected Interface */
		/***********************/


		/********/
		/* Data */
		/********/

		// Time we were created
		protected Time								m_createTime;

		// Test state of tunnel when it generated these results
		protected Tunnel.TunnelTestState		m_testState;

	}

}	// namespace

