/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various stats relating to a tunnel.
 *
 * $Id: TunnelStats.cs,v 1.2 2008/08/07 20:30:30 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System.Collections;

	public class TunnelStats {

		// Construction
		public TunnelStats(TunnelID tid, bool isTest, string connState, string testState,
		string destAddr, uint rawBytesIn, uint rawBytesOut, uint httpBytesIn, uint httpBytesOut,
		User user, ArrayList notifs)
		{
			m_tid = tid;
			m_isTest = isTest;
			m_connState = connState;
			m_testState = testState;
			m_destAddr = destAddr;
			m_rawBytesIn = rawBytesIn;
			m_rawBytesOut = rawBytesOut;
			m_httpBytesIn = httpBytesIn;
			m_httpBytesOut = httpBytesOut;
			m_user = user;
			m_notifs = (ArrayList)notifs.Clone();
		}


		/*************/
		/* Accessors */
		/*************/

		// Get ID of tunnel we are for
		public TunnelID getTID()
		{
			return m_tid;
		}

		// Get whether tunnel is a test tunnel
		public bool isTest()
		{
			return m_isTest;
		}

		// Get tunnel connection state
		public string getConnState()
		{
			return m_connState;
		}

		// Get testing state
		public string getTestState()
		{
			return m_testState;
		}

		// Get destination address
		public string getDestAddr()
		{
			return m_destAddr;
		}

		// Get raw byte counts
		public uint getRawBytesIn()
		{
			return m_rawBytesIn;
		}
		public uint getRawBytesOut()
		{
			return m_rawBytesOut;
		}

		// Get HTTP byte counts
		public uint getHTTPBytesIn()
		{
			return m_httpBytesIn;
		}
		public uint getHTTPBytesOut()
		{
			return m_httpBytesOut;
		}

		// Get user details
		public User getUser()
		{
			return m_user;
		}

		// Get list of received notification msgs
		public ArrayList getNotifs()
		{
			return (ArrayList)m_notifs.Clone();
		}


		/*********************/
		/* Private Interface */
		/*********************/


		/********/
		/* Data */
		/********/

		// TunnelID these stats relate to
		private TunnelID						m_tid;

		// Is it a test tunnel?
		private bool							m_isTest;

		// Connection state
		private string							m_connState;

		// Testing state
		private string							m_testState;

		// Tunnel destination address
		private string							m_destAddr;

		// Data transfer counts
		private uint							m_rawBytesIn;
		private uint							m_rawBytesOut;
		private uint							m_httpBytesIn;
		private uint							m_httpBytesOut;

		// User details
		private User							m_user;

		// Notifications recvd
		private ArrayList						m_notifs;

	}

}	// namespace

