/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating a tunnel has insufficient connections remaining
 * to make it viable.
 *
 * $Id: TunnelUnviableEvent.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{

	public class TunnelUnviableEvent : Event, IdentifyEvent<TunnelID> {

		/***************************/
		/* IdentifyEvent Interface */
		/***************************/

		public bool identify(TunnelID that)
		{
			return (m_tid == that);
		}


		/********************/
		/* Public Interface */
		/********************/

		// Construction
		public TunnelUnviableEvent(Globals glob, Tunneler tunneler, TunnelID tid)
		: base(glob)
		{
			m_tunneler = tunneler;
			m_tid = tid;
		}

		// Run this event
		public override void execute()
		{
			m_glob.DPRINTV("TunnelUnviableEvent::execute()");

			// Let tunnels controlling tunneler know
			m_tunneler.unviableTunnel(m_tid);
		}


		/***********************/
		/* Protected Interface */
		/***********************/

		/********/
		/* Data */
		/********/

		// Controlling tunneler
		protected Tunneler				m_tunneler;

		// ID of tunnel to send msg down
		protected TunnelID				m_tid;

	}

}  // namespace


