/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Class to encode/decode an URL.
 *
 * $Id: URLCode.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;
	using System.Text;

	public class URLCode {

		// Construction
		public URLCode()
		{
		}


		// Encode an URL
		public string encode(string orig)
		{
			StringBuilder encoded = new StringBuilder();

			// Iterator over original string
			for(int pos = 0; pos < orig.Length; pos++) {
				char ch = orig[pos];
				if(!isUnsafe(ch)) {
					// Safe Character
					encoded.Append(ch);
				}
				else {
					// get Hex Value of the Character
					escape(ch, encoded);
				}
			}

			return encoded.ToString();
		}

		// Decode an URL
		public string decode(string orig)
		{
			StringBuilder decoded = new StringBuilder();

			// Iterator over original string
			for(int pos = 0; pos < orig.Length; pos++) {
				char ch = orig[pos];
				if(ch == '%') {
					// Get full escape code
					string esc = orig.Substring(pos + 1, 2);

					// Decode escaped character
					unescape(esc, decoded);

					// Skip remainder of escape code
					pos += 2;
				}
				else {
					decoded.Append(ch);
				}
			}

			return decoded.ToString();
		}


		/*********************/
		/* Private Interface */
		/*********************/

		/***********/
		/* Methods */
		/***********/

		// Is a character unsafe & in need of encoding?
		private bool isUnsafe(char ch)
		{
			if(ch < 32 || ch >= 127)
				return true;

			return (c_unsafeChars.IndexOf(ch) != -1);
		}

		// Escape an unsafe character
		private void escape(char ch, StringBuilder str)
		{
			str.AppendFormat("%{0}{1}", c_hexVals[ch / 16], c_hexVals[ch % 16]);
		}

		// Unescape an usafe character
		private void unescape(string esc, StringBuilder str)
		{
			// Work out ascii value of char
			int ascVal = 0;
			for(int i = 0; i < esc.Length; ++i) {
				char ch = esc[i];
				int val = 0;
				if(ch >= 'A' && ch <= 'F') {
					val = ch - 'A' + 10;
				}
				else {
					val = ch - '0';
				}

				int mult = (esc.Length - i - 1);
				if(mult > 0)
					val *= mult * 16;
				ascVal += val;
			}

			// Write out final char
			str.Append((char)ascVal);
		}


		/********/
		/* Data */
		/********/

		// Static lookup tables
		private static string					c_unsafeChars = " \"<>%\\^[]`+$,@:;/!#?=&{}|";
		private static char[]					c_hexVals = new char[] {
			'0','1','2','3','4','5','6','7','8', '9','A','B','C','D','E','F'
		};

	}

}	// namespace

