/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate some payload data.
 *
 * $Id: Payload.cs,v 1.1 2008/07/25 15:22:38 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

namespace HTTPTunnel
{
	using System;

	public class Payload : IComparable {

		/*************************/
		/* IComparable Interface */
		/*************************/

		// Compare based on sequence number
		public int CompareTo(Object that)
		{
			Payload payload = (Payload)that;
			return (getSeqNo().CompareTo(payload.getSeqNo()));
		}


		/********************/
		/* Public Interface */
		/********************/


		// Construction
		public Payload()
		{
			m_seqNo = new SeqNo(0);
			m_payload = new RawBuff();
			m_split = false;
			m_sent = false;
		}

		public Payload(SeqNo seqNo, RawBuff payload, bool split)
		{
			m_seqNo = new SeqNo(seqNo);
			m_payload = new RawBuff(payload);
			m_split = split;
			m_sent = false;
		}

		public Payload(SeqNo seqNo, RawBuff payload, uint length, bool split)
		{
			m_seqNo = new SeqNo(seqNo);
			m_payload = new RawBuff(payload, length);
			m_split = split;
			m_sent = false;
		}

		public Payload(Payload that)
		{
			m_seqNo = new SeqNo(that.m_seqNo);
			m_payload = new RawBuff(that.m_payload);
			m_split = that.m_split;
			m_sent = that.m_sent;
		}


		/*************/
		/* Accessors */
		/*************/

		// Get sequence number
		public SeqNo getSeqNo()
		{
			return m_seqNo;
		}

		// Get payload data
		public RawBuff getPayload()
		{
			return m_payload;
		}

		// Get payload size (in bytes)
		public uint getPayloadSize()
		{
			return m_payload.getLength();
		}

		// Get payload split indicator
		public bool getSplit()
		{
			return m_split;
		}

		// Get whether we've been sent
		public bool getSent()
		{
			return m_sent;
		}


		/************/
		/* Mutators */
		/************/

		// Set sequence number
		public void setSeqNo(SeqNo seqNo)
		{
			m_seqNo = seqNo;
		}

		// Set payload split indicator
		public void setSplit(bool split)
		{
			m_split = split;
		}

		// Set whether we've been sent
		public void setSent(bool sent)
		{
			m_sent = sent;
		}


		/*********************/
		/* Private Interface */
		/*********************/


		/********/
		/* Data */
		/********/

		// Our sequence number within a tunnel
		private SeqNo					m_seqNo;

		// The actual payload data
		private RawBuff				m_payload;

		// Split payload indicator
		private bool					m_split;

		// Have we been sent?
		private bool					m_sent;

	}

}	// namespace

